==> qtjambi-designer-5.15.4-sources.jar: io/qt/designer/QDesignerMetaDataBaseItemInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerMetaDataBaseItemInterface</p>
 */
public interface QDesignerMetaDataBaseItemInterface extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerMetaDataBaseItemInterface}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerMetaDataBaseItemInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerMetaDataBaseItemInterface.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean enabled(){
                return enabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean enabled_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String name(){
                return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String name_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setEnabled(boolean b){
                setEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), b);
            }
            private native static void setEnabled_native_bool(long __this__nativeId, boolean b);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setName(java.lang.String name){
                setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setTabOrder(java.util.Collection<io.qt.widgets.QWidget> tabOrder){
                setTabOrder_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), tabOrder);
            }
            private native static void setTabOrder_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.widgets.QWidget> tabOrder);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.widgets.QWidget> tabOrder(){
                return tabOrder_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<io.qt.widgets.QWidget> tabOrder_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerMetaDataBaseItemInterface instance);
        
        @io.qt.QtUninvokable
        public abstract boolean enabled();
        
        private native static boolean enabled_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract java.lang.String name();
        
        private native static java.lang.String name_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract void setEnabled(boolean b);
        
        private native static void setEnabled_native_bool(long __this__nativeId, boolean b);
        
        @io.qt.QtUninvokable
        public abstract void setName(java.lang.String name);
        
        private native static void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        @io.qt.QtUninvokable
        public abstract void setTabOrder(java.util.Collection<io.qt.widgets.QWidget> tabOrder);
        
        private native static void setTabOrder_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.widgets.QWidget> tabOrder);
        
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.widgets.QWidget> tabOrder();
        
        private native static java.util.List<io.qt.widgets.QWidget> tabOrder_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public boolean enabled();
    
    @io.qt.QtUninvokable
    public java.lang.String name();
    
    @io.qt.QtUninvokable
    public void setEnabled(boolean b);
    
    @io.qt.QtUninvokable
    public void setName(java.lang.String name);
    
    @io.qt.QtUninvokable
    public void setTabOrder(java.util.Collection<io.qt.widgets.QWidget> tabOrder);
    
    @io.qt.QtUninvokable
    public java.util.List<io.qt.widgets.QWidget> tabOrder();
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QDesignerMetaDataBaseItemInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerMetaDataBaseItemInterface</p>
 */
public interface QDesignerMetaDataBaseItemInterface extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QDesignerMetaDataBaseItemInterface}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QDesignerMetaDataBaseItemInterface
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QDesignerMetaDataBaseItemInterface.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean enabled(){
                return enabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean enabled_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String name(){
                return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String name_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setEnabled(boolean b){
                setEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), b);
            }
            private native static void setEnabled_native_bool(long __this__nativeId, boolean b);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setName(java.lang.String name){
                setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setTabOrder(java.util.Collection<? extends io.qt.widgets.QWidget> tabOrder){
                setTabOrder_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), tabOrder);
            }
            private native static void setTabOrder_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.widgets.QWidget> tabOrder);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.util.List<io.qt.widgets.QWidget> tabOrder(){
                return tabOrder_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.util.List<io.qt.widgets.QWidget> tabOrder_native_constfct(long __this__nativeId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QDesignerMetaDataBaseItemInterface instance);
        
        @io.qt.QtUninvokable
        public abstract boolean enabled();
        
        private native static boolean enabled_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract java.lang.String name();
        
        private native static java.lang.String name_native_constfct(long __this__nativeId);
        
        @io.qt.QtUninvokable
        public abstract void setEnabled(boolean b);
        
        private native static void setEnabled_native_bool(long __this__nativeId, boolean b);
        
        @io.qt.QtUninvokable
        public abstract void setName(java.lang.String name);
        
        private native static void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        @io.qt.QtUninvokable
        public abstract void setTabOrder(java.util.Collection<? extends io.qt.widgets.QWidget> tabOrder);
        
        private native static void setTabOrder_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.widgets.QWidget> tabOrder);
        
        @io.qt.QtUninvokable
        public abstract java.util.List<io.qt.widgets.QWidget> tabOrder();
        
        private native static java.util.List<io.qt.widgets.QWidget> tabOrder_native_constfct(long __this__nativeId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public boolean enabled();
    
    @io.qt.QtUninvokable
    public java.lang.String name();
    
    @io.qt.QtUninvokable
    public void setEnabled(boolean b);
    
    @io.qt.QtUninvokable
    public void setName(java.lang.String name);
    
    @io.qt.QtUninvokable
    public void setTabOrder(java.util.Collection<? extends io.qt.widgets.QWidget> tabOrder);
    
    @io.qt.QtUninvokable
    public java.util.List<io.qt.widgets.QWidget> tabOrder();
    
}
